#!/usr/bin/env bash


DEBUG=true  # oder false

if [ "$DEBUG" = true ]; then
    set -x
fi

pause_if_debug() {
  if [ "$DEBUG" = true ]; then
    printf "🔍 DEBUG: Drücke [Enter] um fortzufahren..."
    read dummy < /dev/tty
  fi
}

# install essentials
echo "📦 Installiere Pakete..."
sudo apt install nala -y
sudo nala install alacritty ninja-build gettext libtool-bin cmake g++ pkg-config unzip curl git tmux build-essential manpages-dev clangd python3-jedi zsh -y
pause_if_debug
clear

echo "Lade Daten"
git clone https://git.boergmann.it/klaas/shellskripte
cd shellskripte
cp ./configs/zshrc ~/.zshrc
cp ./ssh/authorized_keys ~/.ssh/authorized_keys
sudo sh ./ssh/ssh_password -n
pause_if_debug
clear

echo "Installiere Neovim"
cd ~
git clone https://github.com/neovim/neovim
cd neovim
git checkout stable
make CMAKE_BUILD_TYPE=RelWithDebInfo
sudo make install
cd ~
rm -Rf neovim

# config file for nvim
mkdir ~/.config/nvim
cp ~/shellskripte/configs/init.vim ~/.config/nvim/init.vim
sh -c 'curl -fLo "${XDG_DATA_HOME:-$HOME/.local/share}"/nvim/site/autoload/plug.vim --create-dirs \
       https://raw.githubusercontent.com/junegunn/vim-plug/master/plug.vim'
nvim --headless +PlugInstall +qa
# Language support for python and C
nvim --headless -c 'CocInstall -sync coc-python' -c 'qall'
nvim --headless -c 'CocInstall -sync coc-clang' -c 'qall'
pause_if_debug
clear

echo "Installiere nodeJS"
curl -o- https://raw.githubusercontent.com/nvm-sh/nvm/v0.39.3/install.sh | bash
source ~/.bashrc
sh ~/.nvm/nvm.sh
nvm install v20

# usefull packages für nodeJS
npm install -g yarn
npm install -g nodemon

# nvim language support for nodeJS
cd ~/.local/share/nvim/plugged/coc.nvim
yarn install
yarn build

# aufräumen
rm -Rf ~/shellskripte

# zsh nutzen
sudo usermod -s /bin/zsh klaas
